@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 0.7
+    Version ........ 0.8
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -14,13 +14,7 @@
       define('SM_PATH','../../');
 
    function squirrelmail_plugin_init_archive_mail() {
-      global $squirrelmail_plugin_hooks;
-      $squirrelmail_plugin_hooks['mailbox_index_after']['archive_mail'] = 'archive_mail';
-      if (@!function_exists('gzcompress'))
-	   return;
-      $squirrelmail_plugin_hooks['optpage_register_block']['archive_mail'] = 'archive_mail_display_option';
-      $squirrelmail_plugin_hooks['loading_prefs']['archive_mail'] = 'archive_mail_loading_prefs';
-      $squirrelmail_plugin_hooks['move_before_move']['archive_mail'] = 'archive_mail_zipit';
+      include_once(SM_PATH . 'plugins/archive_mail/includes/hooks.php');
    }
 
    function archive_mail_zipit() {
@@ -28,13 +22,17 @@
    }
 
    function archive_mail_version() {
-      return 0.7;
+      return '0.8';
    }
 
    function archive_mail() {
       include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail.php');
    }
 
+   function archive_mail_bottom() {
+      include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail_bottom.php');
+   }
+
    function archive_mail_display_option() {
       include_once(SM_PATH . 'plugins/archive_mail/includes/display_options.php');
    }
